@@ -5,7 +5,7 @@
 ;; Author: Protesilaos Stavrou <info@protesilaos.com>
 ;; URL: https://git.sr.ht/~protesilaos/fontaine
 ;; Mailing list: https://lists.sr.ht/~protesilaos/fontaine
-;; Version: 0.2.2
+;; Version: 0.2.3
 ;; Package-Requires: ((emacs "27.1"))
 
 ;; This file is NOT part of GNU Emacs.
@@ -414,6 +414,7 @@ ARGS are its routines."
    'bold
    (or (plist-get properties :bold-family) 'unspecified)
    (or (plist-get properties :bold-weight) 'bold)
+   (or (plist-get properties :variable-pitch-height) 1.0)
    frame))
 
 (fontaine--apply-preset
@@ -554,7 +555,7 @@ Target FRAME, if provided as an optional argument."
                        (append (alist-get 'fixed-pitch fontaine-font-families)
                                (alist-get 'variable-pitch fontaine-font-families))
                        (font-family-list)))
-         (family (completing-read "Font family of `default' face: "
+         (family (completing-read "Font family of `default': "
                                   families nil t
                                   nil 'fontaine--default-font-family-history))
          (weight (intern (completing-read "Select weight for `default': "
